from unittest import TestCase

from teamgen import (Meeting, MatchRound, Team, Player)


class TestBalancedRound:

    @classmethod
    def setUpTestData(cls):
        pass

    def setUp(self):
        pass

    def test_get_history(self):
        """

        """
        pass